@@ -1,13 +1,15 @@
 # Core
 from fsociety.core.menu import tools_cli
 
-from .nmap import nmap
-from .sqlmap import sqlmap
-from .sublist3r import sublist3r
-from .sherlock import sherlock
+from .gitgraber import gitgraber
+from .hydrarecon import hydrarecon
 from .s3scanner import s3scanner
+from .sherlock import sherlock
+from .sqlmap import sqlmap
+from .striker import striker
+from .sublist3r import sublist3r
 
-__tools__ = [nmap, sqlmap, sublist3r, sherlock, s3scanner]
+__tools__ = [sqlmap, striker, sublist3r, sherlock, s3scanner, gitgraber, hydrarecon]
 
 
 def cli():
