@@ -1,15 +1,16 @@
 import os
 
-from fsociety.core.repo import GitHubRepo
 from fsociety.core.menu import set_readline
-from fsociety.core.usernames import get_usernames, add_username
+from fsociety.core.repo import GitHubRepo
 
 
-class sublist3rRepo(GitHubRepo):
+class Sublist3rRepo(GitHubRepo):
     def __init__(self):
-        super().__init__(path="aboul3la/Sublist3r",
-                         install={"pip": "requirements.txt"}, 
-                         description="Fast subdomains enumeration tool for penetration testers")
+        super().__init__(
+            path="aboul3la/Sublist3r",
+            install={"pip": "requirements.txt"},
+            description="Fast subdomains enumeration tool for penetration testers",
+        )
 
     def run(self):
         os.chdir(self.full_path)
@@ -18,4 +19,4 @@ class sublist3rRepo(GitHubRepo):
         return os.system(f"python3 sublist3r.py -v -d {user_domain}")
 
 
-sublist3r = sublist3rRepo()
+sublist3r = Sublist3rRepo()
