@@ -1,15 +1,16 @@
 import os
 
-from fsociety.core.repo import GitHubRepo
 from fsociety.core.menu import set_readline
-from fsociety.core.usernames import get_usernames, add_username
+from fsociety.core.repo import GitHubRepo
 
 
-class cr3dov3rRepo(GitHubRepo):
+class Cr3dov3rRepo(GitHubRepo):
     def __init__(self):
-        super().__init__(path="D4Vinci/Cr3dOv3r",
-                         install={"pip": "requirements.txt"},
-                         description="Your best friend in credential reuse attacks")
+        super().__init__(
+            path="D4Vinci/Cr3dOv3r",
+            install={"pip": "requirements.txt"},
+            description="Your best friend in credential reuse attacks",
+        )
 
     def run(self):
         os.chdir(self.full_path)
@@ -18,4 +19,4 @@ class cr3dov3rRepo(GitHubRepo):
         return os.system(f"python3 Cr3d0v3r.py {user_email}")
 
 
-cr3dov3r = cr3dov3rRepo()
+cr3dov3r = Cr3dov3rRepo()
