@@ -3,11 +3,13 @@ import os
 from fsociety.core.repo import GitHubRepo
 
 
-class hashBusterRepo(GitHubRepo):
+class HashBusterRepo(GitHubRepo):
     def __init__(self):
-        super().__init__(path="s0md3v/Hash-Buster",
-                         install=None,
-                         description="Why crack hashes when you can bust them?")
+        super().__init__(
+            path="s0md3v/Hash-Buster",
+            install=None,
+            description="Why crack hashes when you can bust them?",
+        )
 
     def run(self):
         os.chdir(self.full_path)
@@ -15,4 +17,4 @@ class hashBusterRepo(GitHubRepo):
         return os.system(f"python3 hash.py -s {user_hash}")
 
 
-hash_buster = hashBusterRepo()
+hash_buster = HashBusterRepo()
