@@ -1,9 +1,10 @@
 # Core
 from fsociety.core.menu import tools_cli
 
+from .photon import photon
 from .xsstrike import xsstrike
 
-__tools__ = [xsstrike]
+__tools__ = [xsstrike, photon]
 
 
 def cli():
