@@ -1,14 +1,16 @@
 import os
 
-from fsociety.core.repo import GitHubRepo
 from fsociety.core.menu import confirm
+from fsociety.core.repo import GitHubRepo
 
 
-class xsstrikeRepo(GitHubRepo):
+class XsstrikeRepo(GitHubRepo):
     def __init__(self):
-        super().__init__(path="s0md3v/XSStrike",
-                         install={"pip": "requirements.txt"}, 
-                         description="Advanced XSS Detection Suite")
+        super().__init__(
+            path="s0md3v/XSStrike",
+            install={"pip": "requirements.txt"},
+            description="Advanced XSS Detection Suite",
+        )
 
     def run(self):
         os.chdir(self.full_path)
@@ -22,4 +24,4 @@ class xsstrikeRepo(GitHubRepo):
         return os.system(f"python3 xsstrike.py --url {user_url} {args_str}")
 
 
-xsstrike = xsstrikeRepo()
+xsstrike = XsstrikeRepo()
